# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .certificate import *
from .consumer import *
from .consumer_acl import *
from .consumer_basic_auth import *
from .consumer_jwt_auth import *
from .consumer_key_auth import *
from .consumer_oauth2 import *
from .plugin import *
from .provider import *
from .route import *
from .service import *
from .target import *
from .upstream import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_kong.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_kong.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "kong",
  "mod": "index/certificate",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumer",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumer:Consumer": "Consumer"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerAcl",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerAcl:ConsumerAcl": "ConsumerAcl"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerBasicAuth",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerBasicAuth:ConsumerBasicAuth": "ConsumerBasicAuth"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerJwtAuth",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerJwtAuth:ConsumerJwtAuth": "ConsumerJwtAuth"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerKeyAuth",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerKeyAuth:ConsumerKeyAuth": "ConsumerKeyAuth"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/consumerOauth2",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/consumerOauth2:ConsumerOauth2": "ConsumerOauth2"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/plugin",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/plugin:Plugin": "Plugin"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/route",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/route:Route": "Route"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/service",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/service:Service": "Service"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/target",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/target:Target": "Target"
  }
 },
 {
  "pkg": "kong",
  "mod": "index/upstream",
  "fqn": "pulumi_kong",
  "classes": {
   "kong:index/upstream:Upstream": "Upstream"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "kong",
  "token": "pulumi:providers:kong",
  "fqn": "pulumi_kong",
  "class": "Provider"
 }
]
"""
)
