# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

kongAdminPassword: Optional[str]
"""
An basic auth password for kong admin
"""

kongAdminToken: Optional[str]
"""
API key for the kong api (Enterprise Edition)
"""

kongAdminUri: Optional[str]
"""
The address of the kong admin url e.g. http://localhost:8001
"""

kongAdminUsername: Optional[str]
"""
An basic auth user for kong admin
"""

kongApiKey: Optional[str]
"""
API key for the kong api (if you have locked it down)
"""

kongWorkspace: Optional[str]
"""
Workspace context (Enterprise Edition)
"""

strictPluginsMatch: Optional[bool]
"""
Should plugins `config_json` field strictly match plugin configuration
"""

tlsSkipVerify: bool
"""
Whether to skip tls verify for https kong api endpoint using self signed or untrusted certs
"""

